==> nextcloud-31.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/logreader/l10n/ja.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "ログ",
    "Errors in the log" : "ログ中のエラー",
    "Failed to get an iterator for log entries: %s" : "ログエントリのイテレータの取得に失敗しました: %s",
    "No errors in the logs since %s" : "ログには%s以降、エラーはありません。",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["ログには %s 以降、エラーが %n 件あります。"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["ログには %s 以降、警告が %n 件あります。"],
    "Log Reader" : "ログリーダー",
    "A log reader for Nextcloud" : "NextCloudのためのログリーダー",
    "Log reader for Nextcloud" : "NextCloudのためのログリーダー",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "エラーと思われる場合は、 {config} の {setting} を確認し、Nextcloud管理マニュアルをご確認ください。",
    "Log reader" : "ログリーダー",
    "Open log reader settings" : "ログリーダーの設定を開く",
    "Log reader settings" : "ログリーダーの設定",
    "Currently the log file {file} is shown" : "現在、ログファイル {file} が表示されています。",
    "Show server log" : "サーバーログを表示",
    "Live view is disabled" : "ライブビューは無効",
    "No log file" : "ログファイルがありません",
    "File-based logging must be enabled to access logs from the Web UI." : "Web UIからログにアクセスするには、ファイルベースのログを有効にする必要があります。",
    "Log entry successfully copied" : "ログが正常にコピーされました",
    "Level" : "レベル",
    "App" : "アプリ",
    "No app in context" : "No app in context",
    "Time" : "時間",
    "Copy raw entry" : "原文のままコピーする",
    "Copy formatted entry" : "フォーマットされたエントリーをコピーする",
    "Hide exception details" : "例外の詳細を非表示にする",
    "View exception details" : "例外の詳細を表示する",
    "Raw log entry" : "原文のログエントリー",
    "Search log entries" : "ログの検索",
    "Caused by {exception}" : "{exception} が原因",
    "Line {line}" : "行 {line}",
    "Filter log levels" : "ログレベルのフィルタ",
    "Set log level" : "ログレベルをセット",
    "Time format" : "時間形式",
    "Live view" : "ライブビュー",
    "Download/Upload logs" : "Download/Upload logs",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "ローカルログファイルを解析できませんでした",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "クリップボードからコピーしたログエントリを表示するには、{keyboardShortcut}を使用してログビューに貼り付けます",
    "Download logs" : "ログのダウンロード",
    "Show local log file" : "ローカルのログファイルを表示する",
    "Upload local log file to be displayed" : "表示するローカルログファイルをアップロードする",
    "Time format used for displaying the timestamp" : "タイムスタンプの表示に使用される時間形式",
    "(Local log files only support the \"raw\" time format)" : "(ローカルログファイルは「未加工」の時間形式のみサポート)",
    "Could not change date time format." : "日付と時刻のフォーマットを変更できませんでした。",
    "Raw data" : "未加工データ",
    "Local time" : "ローカル時間",
    "UTC time" : "UTC時間",
    "Relative" : "相対指定",
    "Could not change live view setting." : "ライブビューの設定を変更できなかった。",
    "Polling is disabled because server is not configured to log to file" : "サーバーがファイルにログを記録するように設定されていないため、ポーリングが無効になっています。",
    "Polling (live view)" : "ポーリング (live view)",
    "Could not set logging levels to show" : "表示するログレベルを設定できませんでした",
    "Filter logging levels" : "ログレベルのフィルター",
    "Could not set logging level" : "ログレベルを設定できませんでした",
    "Set backend loglevel" : "バックエンドのログレベルを設定する",
    "Application" : "アプリケーション",
    "Message" : "メッセージ",
    "Log entry actions" : "Log entry actions",
    "Loading older log entries" : "古いログエントリの読み込み中",
    "No older log entries available" : "古いログエントリーはありません",
    "Collapse row" : "行を折りたたむ",
    "Expand row" : "行を展開する",
    "Show details" : "詳細を見る",
    "Debug" : "デバッグ",
    "Info" : "情報",
    "Warning" : "警告",
    "Error" : "エラー",
    "Fatal" : " 致命的なエラー",
    "Could not load log entries" : "ログエントリーを読み込めませんでした",
    "Clipboard" : "クリップボード",
    "Could not parse clipboard content" : "クリップボードの内容を解析できませんでした",
    "Could not fetch new log entries (server unavailable)" : "新しいログエントリを取得できませんでした（サーバーが使用できません）",
    "Could not fetch new entries" : "新しいエントリーを取得できませんでした",
    "Could not copy to clipboard, please copy manually:" : "クリップボードにコピーできませんでした。手動でコピーしてください：",
    "\tfrom {address} by {user} at {time}\n" : "\tfrom {address} by {user} at {time}\n"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/logreader/l10n/ja.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "ログ",
    "Errors in the log" : "ログ中のエラー",
    "Failed to get an iterator for log entries: %s" : "ログエントリのイテレータの取得に失敗しました: %s",
    "No errors in the logs since %s" : "ログには%s以降、エラーはありません。",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["ログには %s 以降、エラーが %n 件あります。"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["ログには %s 以降、警告が %n 件あります。"],
    "Log Reader" : "ログリーダー",
    "A log reader for Nextcloud" : "NextCloudのためのログリーダー",
    "Log reader for Nextcloud" : "NextCloudのためのログリーダー",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "エラーと思われる場合は、 {config} の {setting} を確認し、Nextcloud管理マニュアルをご確認ください。",
    "Log reader" : "ログリーダー",
    "Open log reader settings" : "ログリーダーの設定を開く",
    "Log reader settings" : "ログリーダーの設定",
    "Currently the log file {file} is shown" : "現在、ログファイル {file} が表示されています。",
    "Show server log" : "サーバーログを表示",
    "Live view is disabled" : "ライブビューは無効",
    "No log file" : "ログファイルがありません",
    "File-based logging must be enabled to access logs from the Web UI." : "Web UIからログにアクセスするには、ファイルベースのログを有効にする必要があります。",
    "Log entry successfully copied" : "ログが正常にコピーされました",
    "Level" : "レベル",
    "App" : "アプリ",
    "No app in context" : "No app in context",
    "Time" : "時間",
    "Copy raw entry" : "原文のままコピーする",
    "Copy formatted entry" : "フォーマットされたエントリーをコピーする",
    "Hide exception details" : "例外の詳細を非表示にする",
    "View exception details" : "例外の詳細を表示する",
    "Raw log entry" : "原文のログエントリー",
    "Search log entries" : "ログの検索",
    "Caused by {exception}" : "{exception} が原因",
    "Line {line}" : "行 {line}",
    "Filter log levels" : "ログレベルのフィルタ",
    "Set log level" : "ログレベルをセット",
    "Time format" : "時間形式",
    "Live view" : "ライブビュー",
    "Download/Upload logs" : "ダウロード/アップロードログ",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "ローカルログファイルを解析できませんでした",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "クリップボードからコピーしたログエントリを表示するには、{keyboardShortcut}を使用してログビューに貼り付けます",
    "Download logs" : "ログのダウンロード",
    "Show local log file" : "ローカルのログファイルを表示する",
    "Upload local log file to be displayed" : "表示するローカルログファイルをアップロードする",
    "Time format used for displaying the timestamp" : "タイムスタンプの表示に使用される時間形式",
    "(Local log files only support the \"raw\" time format)" : "(ローカルログファイルは「未加工」の時間形式のみサポート)",
    "Could not change date time format." : "日付と時刻のフォーマットを変更できませんでした。",
    "Raw data" : "未加工データ",
    "Local time" : "ローカル時間",
    "UTC time" : "UTC時間",
    "Relative" : "相対指定",
    "Could not change live view setting." : "ライブビューの設定を変更できなかった。",
    "Polling is disabled because server is not configured to log to file" : "サーバーがファイルにログを記録するように設定されていないため、ポーリングが無効になっています。",
    "Polling (live view)" : "ポーリング (live view)",
    "Could not set logging levels to show" : "表示するログレベルを設定できませんでした",
    "Filter logging levels" : "ログレベルのフィルター",
    "Could not set logging level" : "ログレベルを設定できませんでした",
    "Set backend loglevel" : "バックエンドのログレベルを設定する",
    "Application" : "アプリケーション",
    "Message" : "メッセージ",
    "Log entry actions" : "Log entry actions",
    "Loading older log entries" : "古いログエントリの読み込み中",
    "No older log entries available" : "古いログエントリーはありません",
    "Collapse row" : "行を折りたたむ",
    "Expand row" : "行を展開する",
    "Show details" : "詳細を見る",
    "Debug" : "デバッグ",
    "Info" : "情報",
    "Warning" : "警告",
    "Error" : "エラー",
    "Fatal" : " 致命的なエラー",
    "Could not load log entries" : "ログエントリーを読み込めませんでした",
    "Clipboard" : "クリップボード",
    "Could not parse clipboard content" : "クリップボードの内容を解析できませんでした",
    "Could not fetch new log entries (server unavailable)" : "新しいログエントリを取得できませんでした（サーバーが使用できません）",
    "Could not fetch new entries" : "新しいエントリーを取得できませんでした",
    "Could not copy to clipboard, please copy manually:" : "クリップボードにコピーできませんでした。手動でコピーしてください：",
    "\tfrom {address} by {user} at {time}\n" : "\tfrom {address} by {user} at {time}\n"
},
"nplurals=1; plural=0;");
